dupin.data.map
-------------------------

.. rubric:: Overview

.. py:currentmodule:: dupin.data.map

.. autosummary::
    :nosignatures:

    CustomMap
    Identity
    Tee

.. rubric:: Details

.. automodule:: dupin.data.map
    :members: CustomMap,
        Identity,
        Tee
